====================================================
``psyclone.domain.common.transformations.alg_trans``
====================================================

.. automodule:: psyclone.domain.common.transformations.alg_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.common.transformations.alg_trans


Classes
=======

- :py:class:`AlgTrans`:
  Transform a generic PSyIR representation of the Algorithm layer to


.. autoclass:: AlgTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: AlgTrans
      :parts: 1
